function LFburst = LF_Burst(tSpike1,tSpike2, s, numspikes, burstISI, scale)

    %MATLAB code for computing the modified Correlation measure, subject to
    %a nonlinear transformation. 
    %
    % ***Note: this has been written for readability, not efficiency*** 
    %
    %Parameters: 
    %tSpike1,2 = spike trains 1 and 2. Vectors of ordered spike times in
    %seconds
    %s = time scale of the correlation measure
    %numspikes = min number of spikes for something to count as a burst
    %burstISI = max ISI for two spikes to be part of the same burst
    %scale = scaling parameter of the nonlinear transformation function
    
    
    
    %to demonstrate this try the following:
    % x = [0.5 1 1.005 1.015 2]
    % y = [0.25 1 1.005 1.015 2.5]
    % LF_Burst(x,y,0.005,3,0.01,.1)
    % and make sure the debugging plot commands are uncommented

   
    
    
    %% Calculate convolution of trains with gaussian kernal
     %estimate the total train length
    l1 = max(tSpike1);
    l2 = max(tSpike2);
    last = max(l1,l2);

     l = last + 5*s;
    %make dt depend on timescale
    
    %make dt depend on timescale
    dt = s/20 ;
    tk = -3*s:dt:3*s;
    t = 0:dt:l;
    
    %convert spike trains to a binary vector, bin size less than 1 ms
    spiketrain1 = zeros(size(t));
    spiketrain2 = zeros(size(t));
    spiketrain1(fix(tSpike1/dt)) = 1;
    spiketrain2(fix(tSpike2/dt)) = 1;
    
    
    
    %represent the Gaussian kernel function
    gkernel = exp(-((tk).^2/(2*(s^2))));
 
    %perform the discrete convolution
    cSpike1 = conv(gkernel,spiketrain1);
    cSpike2 = conv(gkernel,spiketrain2);
    

    

    %% setting numspikes to 1 or fewer results in the normal
    % spike correlation distance being returned
   if numspikes <= 1 
     LFburst2 = 1 - (((dt)*sum((cSpike1.*cSpike2))))/(sqrt((dt)*sum((cSpike1.^2)))*sqrt((dt)*sum((cSpike2.^2))));
   else
    %% Calculate the threshold value, given the numspikes and burstISI
    % parameters.  
       
    % Note: can calcuculate the threshold analytically using the following
    % code (requires the symbolic math toolbox), but faster to do it numerically  
    
    %   syms k;
    %   thr1 = double(symsum(exp(-(((burstISI*(numspikes-1)/2 - (k*burstISI)).^2/(2*(s^2))))), k, 0, numspikes-1));
    %   thr2 = double(symsum(exp(-(((burstISI*(numspikes)/2 - (k*burstISI)).^2/(2*(s^2))))), k, 0, numspikes-1));
    %   thresh = max(thr1,thr2);
    
    testtrain = (1:1:numspikes+1);
    testtrain = testtrain*burstISI;
    thrt = 0:dt:(3*burstISI+(numspikes-1)*burstISI);
    
    ttrain = zeros(size(thrt));
    ttrain(fix(testtrain/dt)) = 1;
    threshtrain = conv(gkernel,ttrain);
    thresh = max(threshtrain);
    
    
    %% calculate the shift
    shift = thresh*scale;
    %this will be in version 2 as well
   
    %% Apply the nonlinear transformation to the convolved trains
    NF1 = heaviside(cSpike1-shift).*(cSpike1-shift);
    NF2 = heaviside(cSpike2-shift).*(cSpike2-shift);
    
    %optional code for plotting examples
    %subplot(6,1,1), plot(spiketrain1)
    %subplot(6,1,2), plot(cSpike1)
    %subplot(6,1,3), plot(NF1)
    %subplot(6,1,4), plot(spiketrain1)
    %subplot(6,1,5), plot(cSpike2)   
    %subplot(6,1,6), plot(NF2)
  
    
    
    %% compute the correlation distance  
    LFburst = 1 - (((dt)*sum((NF1.*NF2))))/(sqrt((dt)*sum((NF1.^2)))*sqrt((dt)*sum((NF2.^2))));

  
   end
    
end