function dSilence = dLFsilence(tSpike1,tSpike2, s)
 
    %MATLAB function to compute the Silence sensitive measure described in (Lyttle, Fellous 2011)  
    %Note: This code has been written with an emphasis on readability and
    %clearly illustrating the workings of the measure. It has not been
    %optimised for speed. 
    
    %Input: 
    % tSpike1 = row vector of spike times, units in seconds
    % tSpike2 = second row vector of spike times, units in seconds
    
    %Parameters:
    % s = length of the delay prior to linear growth (set to mean ISI in the non-silent region of the spike train
    
    %% identify the first and last spikes of the two trains, set boundary conditions
    
    % Note that there is a choice with regard to how to handle the beginning and end of the recordings. In this implementation, 
    % we add artificial spikes to the beginning and end of both trains, that correspond to the fist and last  spikes in both trains. In
    % principle there are alternative choices for handling the boundary
    % conditions

    %find the first spike in either train
    m1 = min(tSpike1);
    m2 = min(tSpike2);
    [first, minI] = min([m1,m2]);
    
    %find the last spike of either train
    l1 = max(tSpike1);
    l2 = max(tSpike2);
    [last, maxI] = max([l1,l2]);
    
    %add artificial beginning and ending spikes to the trains that do not  have them
    if minI == 2
    tSpike1 = [first tSpike1];
    else
    tSpike2 = [first tSpike2];
    end
    if maxI == 2
    tSpike1 = [tSpike1 last];
    else
    tSpike2 = [tSpike2 last];
    end
    
    %scale everything back so that the comparison starts at the first spike
    %in either train, i.e., t=0 at the time of the first spike
    tSpike1 = tSpike1 - first;
    tSpike2 = tSpike2 - first;

    %% map spike trains to functions

    dt = .0005; % sec
    t = 0:dt:last;  
    f = zeros(size(t));
    g = zeros(size(t));

    t1=1;
    for sc1 =1:length(tSpike1) - 1
        tc = 0;
        while tc <= tSpike1(sc1+1) - tSpike1(sc1)   
            if tc <= s
                f(t1) = 0;
                tc = tc+dt;
                t1 = t1+1;
            else
                 f(t1) = tc - s;
                tc = tc+dt;
                t1 = t1+1;
            end
        end
    end 
       
   t2=1;
    for sc2 =1:length(tSpike2) - 1
        tc = 0;
        while tc <= tSpike2(sc2+1) - tSpike2(sc2)   
            if tc <= s
                g(t2) = 0;
                tc = tc+dt;
                t2 = t2+1;
            else
                g(t2) = tc - s;
                tc = tc+dt;
                t2 = t2+1;
            end
        end
    end
    
    %plot commands and such for illustration/debugging
    %t = 0:dt:(dt*(length(f)-1));
    %subplot(2,1,1), plot(t,f)
    %subplot(2,1,2), plot(t,g)
        
    %% compute the correlation measure of the two spike trains
    dSilence = 1 - (((dt)*sum((f.*g))))/(sqrt((dt)*sum((f.^2)))*sqrt((dt)*sum((g.^2))));
    
end