function SimpleRasterPlot(S, names, tstart, tend, height, bar_fraction, offset)
% SimpleRasterPlot(S, height, bar, tstart, tend, height, bar_fraction, offset)
% 
% Plot spike trains as rasters.
%
% INPUT:
% S: cell array of spike trains, all units in seconds
% tstart, tend: the beginning of end of time interval to be plot, default
%
% OPTIONAL INPUTS: 
% 
% height: the height allocated to each cell (includes spacing), default 1
% bar_fraction: the fraction of height occupied by a cell, default 0.8
% offset: Shift on the Y axis
% 
% NSMA- JM modified.

if nargin <5
    height = 1;
    bar_fraction = 0.8;
    offset=0;
end

if tstart ~= 0 & tend < 0 % then you have to find the max in S
  for i = 1:length(S)
      mm(i) = max(S{i});
  end
  tend = max(mm);
end

if tstart > 0
  for i = 1:length(S)
      idx=find(S{i}>tstart & S{i}<tend);
      a=S{i};
    Si{i} = a(idx);
  end
else 
  Si = S;
end


%cla  
hold on
for i = 1:length(Si)
  sp = Si{i};
  sx = [sp sp repmat(NaN, length(sp), 1)];
  sy = repmat([(i*height) (i*height + height *bar_fraction) NaN], length(sp), 1);
  sx = reshape(sx', 1, length(sp)*3);
  sy = reshape(sy', 1, length(sp)*3);
  line(sx, sy+offset, 'Color', 'k','LineWidth',2);          % plot in secs
  if(length(names)>1)
    text(tstart,offset+i*height+i*height/10,names{i},'Rotation',90,'VerticalAlignment','Bottom','interpreter','none')
  end
end
hold off
%axis('tight')
%set(gca,'YTick',[])
xlabel('sec')

