function trains = make_example_trains(numtrains, rate, baselength, numburst, spikesper, burstISI, numgaps, gaplength)

% Code for producing a cell array containing modified Poisson spike trains
% with a specified number of bursts and silences. The generated spike
% trains are vectors of spike times. All time units are in seconds.

%Parameters:
% numtrains - number of trains to generate
% rate - baseline spike rate (in Hz) prior to adding bursts and silences
% baselength - baseline spike train length (in sec.), prior to adding bursts and
% silences
% numburst - number of bursts per train to add
% spikesper - number of spikes per burst
% burstISI - time interval (in sec.) between individual spikes in a burst
% numgaps - number of silences per train to add
% gaplength - length (in sec.) of the silent periods 

trains = cell(1,numtrains);
for ii = 1:numtrains
   
    %% generate a poisson train with rate "rate" and baseline lengths "baselength"
    % a one ms minimum refractory period is artificially imposed, so the train is not a true poisson train
    dt=0.001;
    basespike=[];

    % Generating spikes from a exponential distribution
    for t=0:dt:baselength
        if (rate*dt)>=rand(1)
            basespike(1,end+1)=t;
        end
    end
    %% add a specified number of bursts  of a particular length
    % Here the burst locations are chosen at random for each train, if you
    % want to fix the locations for all trains, set 'burstseed' to a
    % specific vector
    newtimes = basespike;
    burstseed = randi(length(basespike),1,numburst);
    burstseed = sort(burstseed);
    j =1;
    while j <= numburst
        bursttimer = burstISI;
        for i =0:spikesper-2
            newtimes = [newtimes(1:burstseed(j)+ (i)), newtimes(burstseed(j)) + bursttimer, newtimes(burstseed(j)+i +1 :length(newtimes))]; 
            %uncomment the following line to have the intra-burst ISI
            %increase over time
            %bursttimer = bursttimer + (i+2)*burstISI;
        end
        j=j+1;
    end

    bursttrains=sort(newtimes);
    
    %% add a certain number of gaps 
    % Here the gap locations are chosen at random for each train, if you
    % want to fix the locations for all trains, set 'insertlocs' to a
    % specific vector
    new2=bursttrains;
    insertlocs = randi(length(new2), 1,numgaps);
    insertlocs = sort(insertlocs,'descend');
    for s = 1:numgaps        
       new2 = [new2(1:insertlocs(s)), new2((insertlocs(s)+1):end)+gaplength];  
    end
    trains{ii} = new2;
end

end